"""Functions to run tasks on jsonl files."""

import uuid
from lpmn_client_biz import Connection, IOType, Task
from lpmn_client_biz import jsonl_to_directory, archive_to_jsonl, \
    upload, download


def run_json_lines(connection: Connection, lpmn, json_file_path, output_path,
                   column_from_jsonl, columns_from_task, verbose=False):
    """Run a task on a jsonl file.

    :param connection: Task connection
    :type connection: Connection
    :param lpmn: Task lpmn
    :type lpmn: list
    :param json_file_path: path to jsonl file
    :type json_file_path: str
    :param output_path: path to output file
    :type output_path: str
    :param column_from_jsonl: column to use as input
    :type column_from_jsonl: str
    :param columns_from_task: columns form task to add to output
    :type columns_from_task: list
    :param verbose: verbose output, defaults to False
    :type verbose: bool, optional
    """
    input_dir = jsonl_to_directory(json_file_path, column_from_jsonl)
    uploaded = upload(connection, input_dir)
    task = Task([lpmn, 'makezip'], connection)
    result = task.run(uploaded, IOType.FILE, verbose=verbose)
    downloaded = download(
        connection,
        result,
        IOType.FILE,
        filename=f'{uuid.uuid4()}.zip'
    )
    archive_to_jsonl(
        downloaded,
        output_path,
        json_file_path,
        columns_from_task
    )
